| ai_cache | R Documentation |
Download an updated list of information regarding countries, indicators from the World Bank API, Numbers for Development API and No Celings
ai_cache(lang = c("en", "es", "fr", "ar", "zh"))
lang |
Language in which to return the results. If |
A list containing the following items:
Not all data returns have support for langauges other than english. If the specific return
does not support your requested language by default it will return NA.
The options for lang are:
en: English
es: Spanish
fr: French
ar: Arabic
zh: Mandarin
Saving this return and using it has the cache parameter in ai_search and ind_search
replaces the default cached version ai_cachelist that comes with the package itself
# default is english. To specific another language use argument lang
ai_cache(lang = "es")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.