| ai_cachelist | R Documentation |
This data is a cached result of the wbcache function.
By default functions wb and wbsearch use this
data for the cache parameter.
ai_cachelist
A list containing 7 data frames:
countries: A data frame. The result of calling wbcountries
indicators: A data frame.The result of calling wbindicators
sources: A data frame.The result of calling wbsources
datacatalog: A data frame.The result of calling wbdatacatalog
topics: A data frame.The result of calling wbtopics
income: A data frame.The result of calling wbincome
lending: A data frame.The result of calling wblending
This data was updated using wbcache on July 12, 2017
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.